pub struct AgentAdminLinkClaimAttemptToExternalUserRequest {
pub type_: String,
pub claim_attempt_token: SecretString,
pub user: AgentAdminLinkClaimAttemptToExternalUserRequestUser,
pub organization_id: Option<String>,
}Fields
type_: StringThe operation to perform on the claim attempt. Currently only link_external_user is supported.
claim_attempt_token: SecretStringThe token identifying the claim attempt.
user: AgentAdminLinkClaimAttemptToExternalUserRequestUserThe user to attach to the claim attempt, identified by email and external ID.
organization_id: Option<String>The organization to place the agent in. Required when the user belongs to more than one organization.