pub struct CreateMagicCodeAndReturn {
pub email: String,
pub invitation_token: Option<SecretString>,
pub ip_address: Option<String>,
pub user_agent: Option<String>,
pub radar_auth_attempt_id: Option<String>,
pub signals_id: Option<String>,
}Fields
email: StringThe email address to send the magic code to.
invitation_token: Option<SecretString>The invitation token to associate with this magic code.
ip_address: Option<String>The IP address of the user’s request.
user_agent: Option<String>The user agent string from the user’s request.
radar_auth_attempt_id: Option<String>The ID of an existing Radar authentication attempt to associate with this request.
signals_id: Option<String>An optional Radar signals ID to correlate client-side signals with this request.