pub struct Directory {
pub object: String,
pub id: String,
pub organization_id: String,
pub external_key: String,
pub type_: DirectoryType,
pub state: DirectoryState,
pub name: String,
pub domain: Option<String>,
pub metadata: Option<DirectoryMetadata>,
pub created_at: String,
pub updated_at: String,
}Fields
object: StringDistinguishes the Directory object.
id: StringUnique identifier for the Directory.
organization_id: StringThe unique identifier for the Organization in which the directory resides.
external_key: StringExternal Key for the Directory.
type_: DirectoryTypeThe type of external Directory Provider integrated with.
state: DirectoryStateDescribes whether the Directory has been successfully connected to an external provider.
name: StringThe name of the directory.
domain: Option<String>The URL associated with an Enterprise Client.
metadata: Option<DirectoryMetadata>Aggregate counts of directory users and groups synced from the provider.
created_at: StringAn ISO 8601 timestamp.
updated_at: StringAn ISO 8601 timestamp.