DirectoryUser

Struct DirectoryUser 

pub struct DirectoryUser {
Show 19 fields pub object: String, pub id: String, pub directory_id: String, pub organization_id: String, pub idp_id: String, pub email: Option<String>, pub first_name: Option<String>, pub last_name: Option<String>, pub name: Option<String>, pub emails: Option<Vec<DirectoryUserEmail>>, pub job_title: Option<String>, pub username: Option<String>, pub state: DirectoryUserState, pub raw_attributes: HashMap<String, Value>, pub custom_attributes: HashMap<String, Value>, pub role: Option<SlimRole>, pub roles: Option<Vec<SlimRole>>, pub created_at: String, pub updated_at: String,
}

Fields

object: String

Distinguishes the Directory User object.

id: String

Unique identifier for the Directory User.

directory_id: String

The identifier of the Directory the Directory User belongs to.

organization_id: String

The identifier for the Organization in which the Directory resides.

idp_id: String

Unique identifier for the user, assigned by the Directory Provider. Different Directory Providers use different ID formats.

email: Option<String>

The email address of the user.

first_name: Option<String>

The first name of the user.

last_name: Option<String>

The last name of the user.

name: Option<String>

The full name of the user.

emails: Option<Vec<DirectoryUserEmail>>
👎Deprecated

A list of email addresses for the user.

job_title: Option<String>
👎Deprecated

The job title of the user.

username: Option<String>
👎Deprecated

The username of the user.

state: DirectoryUserState

The state of the user.

raw_attributes: HashMap<String, Value>
👎Deprecated

The raw attributes received from the directory provider.

custom_attributes: HashMap<String, Value>

An object containing the custom attribute mapping for the Directory Provider.

role: Option<SlimRole>roles: Option<Vec<SlimRole>>

All roles assigned to the user.

created_at: String

An ISO 8601 timestamp.

updated_at: String

An ISO 8601 timestamp.