pub struct EnrollUserAuthenticationFactor {
pub type_: String,
pub totp_issuer: Option<String>,
pub totp_user: Option<String>,
pub totp_secret: Option<SecretString>,
}Fields
type_: StringThe type of the factor to enroll.
totp_issuer: Option<String>Your application or company name displayed in the user’s authenticator app.
totp_user: Option<String>The user’s account name displayed in their authenticator app.
totp_secret: Option<SecretString>The Base32-encoded shared secret for TOTP factors. This can be provided when creating the auth factor, otherwise it will be generated. The algorithm used to derive TOTP codes is SHA-1, the code length is 6 digits, and the timestep is 30 seconds – the secret must be compatible with these parameters.