pub struct OrganizationListListMetadata {
pub before: Option<String>,
pub after: Option<String>,
}Expand description
Pagination cursors for navigating between pages of results.
Fields
before: Option<String>An object ID that defines your place in the list. When the ID is not present, you are at the start of the list.
after: Option<String>An object ID that defines your place in the list. When the ID is not present, you are at the end of the list.