pub struct UserInvite {Show 15 fields
pub object: String,
pub id: String,
pub email: String,
pub state: UserInviteState,
pub accepted_at: Option<String>,
pub revoked_at: Option<String>,
pub expires_at: String,
pub organization_id: Option<String>,
pub inviter_user_id: Option<String>,
pub accepted_user_id: Option<String>,
pub role_slug: Option<String>,
pub created_at: String,
pub updated_at: String,
pub token: SecretString,
pub accept_invitation_url: String,
}Fields
object: StringDistinguishes the invitation object.
id: StringThe unique ID of the invitation.
email: StringThe email address of the recipient.
state: UserInviteStateThe state of the invitation.
accepted_at: Option<String>The timestamp when the invitation was accepted, or null if not yet accepted.
revoked_at: Option<String>The timestamp when the invitation was revoked, or null if not revoked.
expires_at: StringThe timestamp when the invitation expires.
organization_id: Option<String>The ID of the organization that the recipient will join.
inviter_user_id: Option<String>The ID of the user who invited the recipient, if provided.
accepted_user_id: Option<String>The ID of the user who accepted the invitation, once accepted.
role_slug: Option<String>Slug of the role the invitee will be assigned on acceptance. Reflects the current role on the invitee’s organization membership. null when the invitation has no associated organization.
created_at: StringAn ISO 8601 timestamp.
updated_at: StringAn ISO 8601 timestamp.
token: SecretStringThe token used to accept the invitation.
accept_invitation_url: StringThe URL where the recipient can accept the invitation.