ListRoleAssignmentsForResourceByExternalIdParams

Struct ListRoleAssignmentsForResourceByExternalIdParams 

pub struct ListRoleAssignmentsForResourceByExternalIdParams {
    pub before: Option<String>,
    pub after: Option<String>,
    pub limit: Option<i64>,
    pub order: Option<PaginationOrder>,
    pub role_slug: Option<String>,
}

Fields

before: Option<String>

An object ID that defines your place in the list. When the ID is not present, you are at the end of the list. For example, if you make a list request and receive 100 objects, ending with "obj_123", your subsequent call can include before="obj_123" to fetch a new batch of objects before "obj_123".

after: Option<String>

An object ID that defines your place in the list. When the ID is not present, you are at the end of the list. For example, if you make a list request and receive 100 objects, ending with "obj_123", your subsequent call can include after="obj_123" to fetch a new batch of objects after "obj_123".

limit: Option<i64>

Upper limit on the number of objects to return, between 1 and 100.

Defaults to 10.

order: Option<PaginationOrder>

Order the results by the creation time. Supported values are "asc" (ascending), "desc" (descending), and "normal" (descending with reversed cursor semantics where before fetches older records and after fetches newer records).

Defaults to desc.

role_slug: Option<String>

Filter assignments by the slug of the role.