pub struct ListUserAuthFactorsParams {
pub before: Option<String>,
pub after: Option<String>,
pub limit: Option<i64>,
pub order: Option<PaginationOrder>,
}Fields
before: Option<String>An object ID that defines your place in the list. When the ID is not present, you are at the end of the list.
after: Option<String>An object ID that defines your place in the list. When the ID is not present, you are at the end of the list.
limit: Option<i64>Upper limit on the number of objects to return, between 1 and 100.
Defaults to 10.
order: Option<PaginationOrder>Order the results by the creation time.
Defaults to desc.