pub struct DataIntegrationsGetDataIntegrationAuthorizeUrlRequest {
pub user_id: String,
pub organization_id: Option<String>,
pub return_to: Option<String>,
pub config: Option<HashMap<String, String>>,
}Fields
user_id: StringThe ID of the user to authorize.
organization_id: Option<String>An organization ID to scope the authorization to a specific organization.
return_to: Option<String>The URL to redirect the user to after authorization.
config: Option<HashMap<String, String>>Connect-time config values for the provider-declared installation-scope fields (e.g. a Zendesk subdomain), keyed by the config field. Only fields the provider declares may be supplied, and required fields must be provided unless already pinned on the integration.